Enum Event
#[non_exhaustive]pub enum Event {
ModeSuccessful,
ModeFailed,
PresentCancelled,
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ModeSuccessful
mode switch succeeded
This event indicates that the attempted mode switch operation was successful. A surface of the size requested in the mode switch will fill the output without scaling.
Upon receiving this event, the client should destroy the wl_fullscreen_shell_mode_feedback object.
This is a destructor, once received this object cannot be used any longer.
ModeFailed
mode switch failed
This event indicates that the attempted mode switch operation failed. This may be because the requested output mode is not possible or it may mean that the compositor does not want to allow it.
Upon receiving this event, the client should destroy the wl_fullscreen_shell_mode_feedback object.
This is a destructor, once received this object cannot be used any longer.
PresentCancelled
mode switch cancelled
This event indicates that the attempted mode switch operation was cancelled. Most likely this is because the client requested a second mode switch before the first one completed.
Upon receiving this event, the client should destroy the wl_fullscreen_shell_mode_feedback object.
This is a destructor, once received this object cannot be used any longer.
Implementations